#
# spec file for package maven-dependency-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-dependency-plugin
VCS: https://src.suse.de/SLFO-pool/maven-dependency-plugin#a657761b122d85727ce1065e7c3c69c22fd02d01fb604fbbee84effd13327c02
Version:        3.8.1
Release:        160000.1.3
Summary:        Plugin to manipulate, copy and unpack local and remote artifacts
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            http://maven.apache.org/plugins/%{name}
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugins/%{name}/%{version}/%{name}-%{version}-source-release.zip
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(javax.inject:javax.inject)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.maven.doxia:doxia-sink-api)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-api)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-impl)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-api)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-util)
BuildRequires:  mvn(org.apache.maven.shared:maven-artifact-transfer)
BuildRequires:  mvn(org.apache.maven.shared:maven-common-artifact-filters)
BuildRequires:  mvn(org.apache.maven.shared:maven-dependency-analyzer) >= 1.14.1
BuildRequires:  mvn(org.apache.maven.shared:maven-dependency-tree)
BuildRequires:  mvn(org.apache.maven.shared:maven-shared-utils)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven:maven-repository-metadata)
BuildRequires:  mvn(org.apache.maven:maven-resolver-provider)
BuildRequires:  mvn(org.apache.maven:maven-settings)
BuildRequires:  mvn(org.codehaus.plexus:plexus-archiver)
BuildRequires:  mvn(org.codehaus.plexus:plexus-i18n)
BuildRequires:  mvn(org.codehaus.plexus:plexus-io)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.codehaus.plexus:plexus-xml)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.sonatype.plexus:plexus-build-api)
BuildArch:      noarch

%description

The dependency plugin provides the capability to manipulate
artifacts. It can copy and/or unpack artifacts from local or remote
repositories to a specified location.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
%{summary}.

%prep
%setup -q

%build
# Tests require legacy Maven
%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE
%doc NOTICE

%changelog
* Tue Oct 29 2024 fstrba@suse.com
- Upgrade to verion 3.8.1
  * Bug
    + MDEP-956: silent parameter is not taken into account
  * New Feature
    + MDEP-957: Special case slf4j-simple et al to not report used
    but undeclared
  * Improvement
    + MDEP-932: Don't log successful file copies
  * Test
    + MDEP-930: runTreeMojo in TestTreeMojo ignores encoding
  * Dependency upgrade
    + MDEP-958: maven-dependency-analyzer to 1.15.0
    + MDEP-961: Upgrade to Doxia 2.0.0 GA Stack
* Tue Oct 15 2024 fstrba@suse.com
- Upgrade to version 3.8.0
  * Bug
    + MDEP-875: Regression: list-repositories may produce NPE
    + MDEP-835: dependency:tree no longer shows optional flag
    + MDEP-838: "Artifact has not been packaged yet" error message
    is not very helpful
    + MDEP-938: 'mdep.overIfNewer' is misnamed from its usage of
    'mdep.overWriteIfNewer'
    + MDEP-943: [REGRESSION] appendOutput for tree goal broken for
    multi-module project
  * New Feature
    + MDEP-317: Add goal dependency:analyze-exclusions - check for
    invalid excludes
    + MDEP-799: improve mvn dependency:tree - add optional JSON
    output of the results
    + MDEP-928: Allow to exclude classes from dependency:analyze
  * Improvement
    + MDEP-669: Optimize the documentation of <outputProperty> of
    build-classpath-mojo
    + MDEP-893: Get rid of commons-lang3
    + MDEP-894: Use @Component instead of @Parameter for
    session/project
    + MDEP-896: Removing unused code
    + MDEP-897: Remove old style JavaDoc Plexus docs
    + MDEP-899: Upgrade maven-plugin parent to 42
    + MDEP-917: dependency:analyze-exclusions - use Resolver API
    instead of ProjectBuilder
    + MDEP-924: Get rid of maven-artifact-transfer from list-classes
    goal
    + MDEP-925: Require Maven 3.6.3
    + MDEP-939: Lock down classifier in dependency:sources goal
    + MDEP-940: Use Resolver API instead of m-a-t for resolving
    artifacts
  * Test
    + MDEP-710: reenable TestTreeMojo
  * Task
    + MDEP-912: Use version for plexus-utils/plexus-xml  from parent
    + MDEP-914: collect goal description broken in documentation
    + MDEP-918: Use standard updatePolicy for repositories in ITs
    + MDEP-923: Code cleanups
    + MDEP-935: Improvement ITs for dependency:tree
    + MDEP-941: Deprecate dependency:sources in favor of
    dependency:resolve-sources
    + MDEP-945: Fix documentation about get goal
    + MDEP-913: dependency:collect missing from index page
* Wed Sep 27 2023 fstrba@suse.com
- Update to version 3.6.0
  * Bug
    + MDEP-660: Obsolete example of -Dverbose on web page
    + MDEP-671: Unsupported verbose option still appears in docs
    + MDEP-680: dependency:go-offline does not use repositories from
    parent pom in reactor build
    + MDEP-700: Fix possible NPE
    + MDEP-693: `dependency:analyze-only` goal fails on OpenJDK 14
    + MDEP-698: FileWriter and FileReader should be replaced
    + MDEP-739: Dependency Plugin go-offline doesn't respect
    artifact classifier
    + MDEP-740: analyze-only failed: Unsupported class file major
    version 60 (Java 16)
    + MDEP-747: analyze-only failed: Unsupported class file major
    version 61 (Java 17)
    + MDEP-749: copy-dependencies fails when using excludeScope=test
    + MDEP-679: mvn dependency:analyze detected wrong transitive
    dependency
    + MDEP-742: dependency plugin does not work with JDK 16
    + MDEP-752: skip dependency analyze in ear packaging
    + MDEP-753: Non-test dependency reported as Non-test scoped test
    only dependency
    + MDEP-759: 'Dependency not found' with 3.2.0 and Java-17 while
    analyzing
    + MDEP-761: Tree plugin does not terminate with 3.2.0
    + MDEP-769: Minor improvement - continue
    + MDEP-774: analyze-only failed: PermittedSubclasses requires
    ASM9
    + MDEP-781: Broken Link to "Introduction to Dependency Mechanism
    Page"
    + MDEP-783: TreeMojo docs say scope doesn't work due to
    MSHARED-4
    + MDEP-786: Sealed classes not supported
    + MDEP-806: Dependency tree in verbose mode for war is empty
    + MDEP-809: Javadoc was not updated to reflect that :tree's
    verbose option is now ok
    + MDEP-630: error dependency:list (caused by postgresql
    dependency)
    + MDEP-842: :list-classes does not skip if skip is set
    + MDEP-843: :list-classes does not use GAV parameters
  * New Feature
    + MDEP-644: Reintroduce the verbose option for dependency:tree
    + MDEP-645: List classes in a given artifact
    + MDEP-708: dependency:analyze should recommend narrower scope
    where possible
    + MDEP-714: Add analyze parameter "ignoreUnusedRuntime"
    + MDEP-787: Allow ignoring non-test-scoped dependencies
    + MDEP-782: Add a <stripType> option to unpack goals
    + MDEP-804: Allow auto-ignore of all non-test scoped
    dependencies used only in test scope
  * Improvement
    + MDEP-705: Unused method o.a.m.p.d.t.TreeMojo.containsVersion
    + MDEP-763: Minor improvements
    + MDEP-768: GitHub Action build improvement
    + MDEP-779: dependency:analyze should list the classes that
    cause a used undeclared dependency
    + MDEP-789: Improve documentation of analyze - Non-test scoped
    + MDEP-602: Turn warnings into errors instead of failOnWarning
    + MDEP-674: maven-dependency-plugin should leverage
    plexus-build-api to support IDEs
    + MDEP-716: TestListClassesMojo logs too much
    + MDEP-827: Use outputDirectory from AbstractMavenReport
    + MDEP-831: Remove not used dependencies / Replace parts
    + MDEP-853: list-repositories - improvements
    + MDEP-862: warns about depending on plexus-container-default
    + MDEP-864: Replace AnalyzeReportView with a new
    AnalyzeReportRenderer
  * Task
    + MDEP-681: Remove no longer required exclusions
    + MDEP-760: Java 1.8 as minimum
    + MDEP-841: Explicitly start and end tables with Doxia Sinks in
    report renderers
    + MDEP-849: Replace Maven shared StringUtils with Commons Lang3
    + MDEP-855: Remove unused and ignored parameter - useJvmChmod
    + MDEP-857: Remove custom plexus configuration
    + MDEP-859: Code refactor - UnpackUtil
    + MDEP-866: Refresh download page
* Wed Dec 30 2020 jgwang@suse.com
- Update to version 3.1.2
  * Upgrade maven-plugins parent to version 32
  * Upgrade plexus-io to 3.1.0
  * Upgrade maven-shared-utils 3.2.1
  * Upgrade plexus-archiver to 4.1.0
  * Upgrade maven-artifact-transfer to 0.11.0
  * Upgrade plexus-utils to 3.2.0
  * Upgrade plexus-utils to 3.3.0
  * Upgrade maven-common-artifact-filters to 3.1.0
  * Upgrade parent POM from 32 to 33
  * Upgrade maven-dependency-analyzer to 1.11.1
  * Update ASM so it works with Java 13
  * Add note on dependecy:tree -Dverbose support in 3.0+
  * Add a TOC to ease navigating to each goal usage
  * Remove @param for a parameter which does not exists.
  * Remove newline and trailing space from log line.
  * Remove deprecated call.
  * Fix link to mailing list
  * Fix JavaDoc issue.
  * Use https for sigs, hashes and KEYS
  * Use sha512 checksums instead of sha1
  * Switch to asfMavenTlpPlgnBuild
  * Unpacking File Mappers
  * Replace CapturingLog class with Mockito usage
  * Rewrite go-offline so it resembles resolve-plugins
  * Perform transformation to artifact keys just once
- Removed patch:
  * 00-maven-artifact-transfer-0.11.0.patch
    + not needed with this version any more
* Mon Nov 25 2019 fstrba@suse.com
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
- Added patch:
  * 00-maven-artifact-transfer-0.11.0.patch
    + Fix build against maven-artifact-transfer >= 0.11
* Fri Apr  5 2019 fstrba@suse.com
- Initial packaging of maven-dependency-plugin 3.1.1
